[ARVADOS] updated: 1.3.0-1718-g800b63d7c

Git user git at public.curoverse.com
Fri Oct 11 17:16:39 UTC 2019


Summary of changes:
 sdk/cwl/tests/test_container.py | 14 +++++++++-----
 1 file changed, 9 insertions(+), 5 deletions(-)

       via  800b63d7cad00988778d0610294c305f3facac6a (commit)
      from  cbdda43d034b07bfeba9f711e4821c5c28c08e7f (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.


commit 800b63d7cad00988778d0610294c305f3facac6a
Author: Peter Amstutz <pamstutz at veritasgenetics.com>
Date:   Fri Oct 11 13:16:23 2019 -0400

    15694: Improve test comments/assertions
    
    Arvados-DCO-1.1-Signed-off-by: Peter Amstutz <pamstutz at veritasgenetics.com>

diff --git a/sdk/cwl/tests/test_container.py b/sdk/cwl/tests/test_container.py
index b1034222e..cb6cfbadb 100644
--- a/sdk/cwl/tests/test_container.py
+++ b/sdk/cwl/tests/test_container.py
@@ -535,19 +535,23 @@ class TestContainer(unittest.TestCase):
             self.fail("RuntimeStatusLoggingHandler should not be called recursively")
 
 
     # Test to make sure that an exception raised from get_current_container doesn't
     @mock.patch("arvados_cwl.util.get_current_container")
     def test_runtime_status_get_current_container_exception(self, gcc_mock):
         self.setup_and_test_container_executor_and_logging(gcc_mock)
         root_logger = logging.getLogger('')
 
         # get_current_container is invoked when we call runtime_status_update
         # so try and log again!
         gcc_mock.side_effect = Exception("Second Error")
         try:
             root_logger.error("First Error")
-        except RuntimeError:
-            self.fail("RuntimeStatusLoggingHandler should not be called recursively")
+        except Exception:
+            self.fail("Exception in logger should not propagate")
+        self.assertTrue(gcc_mock.called)
 
     @mock.patch("arvados_cwl.ArvCwlExecutor.runtime_status_update")
     @mock.patch("arvados_cwl.util.get_current_container")

-----------------------------------------------------------------------
@@ -535,19 +535,23 @@ class TestContainer(unittest.TestCase):
 
 
-    # Test to make sure that an exception raised from get_current_container doesn't
+    # Test to make sure that an exception raised from
+    # get_current_container doesn't cause the logger to raise an
+    # exception
     @mock.patch("arvados_cwl.util.get_current_container")
     def test_runtime_status_get_current_container_exception(self, gcc_mock):
@@ -535,19 +535,23 @@ class TestContainer(unittest.TestCase):
         root_logger = logging.getLogger('')
 
-        # get_current_container is invoked when we call runtime_status_update
-        # so try and log again!
+        # get_current_container is invoked when we call
+        # runtime_status_update, it is going to also raise an
+        # exception.
         gcc_mock.side_effect = Exception("Second Error")
         try:


hooks/post-receive
-- 




More information about the arvados-commits mailing list